@@ -1,15 +1,18 @@
-mod cli;
-mod cook;
-mod rule;
-mod tree;
-mod node;
-
+/// Overview: Read, process and write.
 use std::fs::{File, OpenOptions};
 use std::io::{BufReader, Read, Write};
+
 use anyhow::Result;
 use structopt::StructOpt;
-use crate::cook::cook;
+
 use crate::cli::Opt;
+use crate::cook::cook;
+
+mod cli;
+mod cook;
+mod node;
+mod rule;
+mod tree;
 
 fn main() -> Result<()> {
     let Opt { input, output } = Opt::from_args();
@@ -22,17 +25,16 @@ fn main() -> Result<()> {
 
     let mut output_file;
     match output {
-        Some(file) => output_file = OpenOptions::new()
-            .write(true)
-            .create(true)
-            .truncate(true)
-            .open(file)?,
-        None => output_file = OpenOptions::new()
-            .write(true)
-            .truncate(true)
-            .open(&input)?,
+        Some(file) => {
+            output_file = OpenOptions::new()
+                .write(true)
+                .create(true)
+                .truncate(true)
+                .open(file)?
+        }
+        None => output_file = OpenOptions::new().write(true).truncate(true).open(&input)?,
     }
     write!(output_file, "{}", output_content)?;
 
     Ok(())
-}
\ No newline at end of file
+}
